@@ -1,9 +1,6 @@
 import base64
 import json
 import time
-# REMOVE
-import logging
-gunicorn_logger = logging.getLogger("gunicorn.error")
 
 from functools import wraps
 
@@ -17,29 +14,14 @@ def _wrap(f):
     @wraps(f)
     def wrapper(*args, **kwgs):
         if kwgs.pop("gcp_auth", True) is False:
-            # REMOVE
-            gunicorn_logger.info("gcp_auth set to false, using normal requests")
-
             return f(*args, **kwgs)
 
-        # REMOVE
-        gunicorn_logger.info(f"args: {args}")
-
         url = args[0]
         headers = kwgs.pop("headers", None) or {}
         jwt = cached_jwt.get(url, None)
         if _jwt_expired(jwt):
-            # REMOVE
-            gunicorn_logger.info(f"jwt expired or not set for {url}, refreshing")
-
             jwt = _get_gcp_auth_token(url)
             cached_jwt[url] = jwt
-        # REMOVE
-        else:
-            gunicorn_logger.info(f"using cached jwt for {url}")
-
-        # REMOVE
-        gunicorn_logger.info(f"request {url} -> {jwt}")
 
         headers.update({"Authorization": f"bearer {jwt}"})
         return f(*args, headers=headers, **kwgs)
